@@ -1,11 +1,12 @@
 import io
 from enum import Enum
+from pathlib import Path
 from typing import Type
 
 import pandas as pd
 from pydantic import BaseModel, Field
-from pymultirole_plugins.formatter import FormatterBase, FormatterParameters
-from pymultirole_plugins.schema import Document
+from pymultirole_plugins.v1.formatter import FormatterBase, FormatterParameters
+from pymultirole_plugins.v1.schema import Document
 from starlette.responses import Response
 
 
@@ -61,9 +62,13 @@ class TabularFormatter(FormatterBase):
             if parameters.format == OutputFormat.xlsx:
                 bio = io.BytesIO()
                 df.to_excel(bio)
+                filename = f"file.{OutputFormat.xlsx.value}"
+                if document.properties and "fileName" in document.properties:
+                    filepath = Path(document.properties['fileName'])
+                    filename = f"{filepath.stem}.{OutputFormat.xlsx.value}"
                 resp = Response(content=bio.getvalue(),
                                 media_type="application/vnd.openxmlformats-officedocument.spreadsheetml.sheet")
-                resp.headers["Content-Disposition"] = f"attachment; filename=file.{OutputFormat.xlsx.value}"
+                resp.headers["Content-Disposition"] = f"attachment; filename={filename}"
             elif parameters.format == OutputFormat.csv:
                 sio = io.StringIO()
                 df.to_csv(sio, index=False)
